Welcome to the project's homepage.

The purpose of this package is ...


SCOPE
...


DESCRIPTION
...


QUICKSTART USAGE EXAMPLES
...


USAGE GUIDE
...


INTERESTED ON COLLABORATING AS A DEVELOPER IN OUR PROJECT?
...


THANKS FOR YOUR SUPPORT!
We are happy to develop applications that can contribute to as many people as possible. If you like our applications and are interested in supporting our work, you can make a donation or buy me a coffee: buymeacoffee.com/...